# wikiwho_pickle
script and dependencies to open a wikiwho pickle independent of the API infraestructure


# Install

```
pip install git+git://github.com/gesiscss/wikiwho_pickle.git@master
```

***or***, add this line to the `requirements.txt` file:

```
git+git://github.com/gesiscss/wikiwho_pickle.git@master#egg=wikiwho_pickle
```

and execute `pip install -r requirements.txt`


# Example

See the `example.py` file.
